package org.jeecg.modules.api.communityController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.api.bean.PageBean;
import org.jeecg.modules.api.service.ActivityService;
import org.jeecg.modules.api.service.IndexService;
import org.jeecg.modules.communityActivity.entity.CommunityActivity;
import org.jeecg.modules.communityActivityApply.entity.CommunityActivityApply;
import org.jeecg.modules.communityActivityCollection.entity.CommunityActivityCollection;
import org.jeecg.modules.communityBanner.entity.CommunityBanner;
import org.jeecg.modules.communityGoodsCollection.entity.CommunityGoodsCollection;
import org.jeecg.modules.communityVolunteer.entity.CommunityVolunteer;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

@Api(tags="活动-相关接口")
@RestController
@RequestMapping("/community/activity")
@Slf4j
public class ActivityController {

    /******************************************************************************************************************/
    @Resource
    private ActivityService activityService;
    /******************************************************************************************************************/

    //获取活动列表
    @ApiOperation(value="活动-获取活动列表", notes="活动-获取活动列表")
    @RequestMapping(value = "/queryActivityList", method = {RequestMethod.GET})
    public Result<?> queryActivityList(CommunityActivity communityActivity, PageBean pageBean){
        return activityService.queryActivityList(communityActivity, pageBean);
    }

    //获取活动详情
    @ApiOperation(value="活动-获取活动详情", notes="活动-获取活动详情")
    @RequestMapping(value = "/queryActivityById", method = {RequestMethod.GET})
    public Result<?> queryActivityById(String activityId){
        return activityService.queryActivityById(activityId);
    }

    //收藏活动
    @ApiOperation(value="活动-收藏活动", notes="活动-收藏活动")
    @RequestMapping(value = "/collectionActivity", method = {RequestMethod.POST})
    public Result<?> collectionActivity(@RequestHeader("X-Access-Token") String token, CommunityActivityCollection communityActivityCollection){
        return activityService.collectionActivity(token, communityActivityCollection);
    }

    //活动报名
    @ApiOperation(value="活动-活动报名", notes="活动-活动报名")
    @RequestMapping(value = "/applyActivity", method = {RequestMethod.POST})
    public Result<?> applyActivity(@RequestHeader("X-Access-Token") String token, CommunityActivityApply communityActivityApply){
        return activityService.applyActivity(token, communityActivityApply);
    }

    //获取我收藏的活动列表
    @ApiOperation(value="活动收藏-获取我收藏的活动列表", notes="活动收藏-获取我收藏的活动列表")
    @RequestMapping(value = "/queryActivityCollectionList", method = {RequestMethod.POST})
    public Result<?> queryActivityCollectionList(@RequestHeader("X-Access-Token") String token, PageBean pageBean){
        return activityService.queryActivityCollectionList(token, pageBean);
    }

    //获取我报名的活动列表
    @ApiOperation(value="我的报名-获取我报名的活动列表", notes="我的报名-获取我报名的活动列表")
    @RequestMapping(value = "/queryApplyList", method = {RequestMethod.POST})
    public Result<?> queryApplyList(@RequestHeader("X-Access-Token") String token, CommunityActivityApply communityActivityApply, PageBean pageBean){
        return activityService.queryApplyList(token, communityActivityApply, pageBean);
    }

    //活动签到
    @ApiOperation(value="我的报名-活动签到", notes="我的报名-活动签到")
    @RequestMapping(value = "/signActivity", method = {RequestMethod.POST})
    public Result<?> signActivity(@RequestHeader("X-Access-Token") String token, String activityId){
        return activityService.signActivity(token, activityId);
    }


}
