package org.jeecg.modules.api.communityController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.api.bean.PageBean;
import org.jeecg.modules.api.service.GoodsService;
import org.jeecg.modules.api.service.IndexService;
import org.jeecg.modules.communityBanner.entity.CommunityBanner;
import org.jeecg.modules.communityGoods.entity.CommunityGoods;
import org.jeecg.modules.communityGoodsCollection.entity.CommunityGoodsCollection;
import org.jeecg.modules.communityOrder.entity.CommunityOrder;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

@Api(tags="商品-相关接口")
@RestController
@RequestMapping("/community/goods")
@Slf4j
public class GoodsController {
    /******************************************************************************************************************/
    @Resource
    private GoodsService goodsService;
    /******************************************************************************************************************/

    //获取商品列表
    @ApiOperation(value="首页-获取商品列表", notes="首页-获取商品列表")
    @RequestMapping(value = "/queryGoodsList", method = {RequestMethod.GET})
    public Result<?> queryGoodsList(CommunityGoods communityGoods, PageBean pageBean){
        return goodsService.queryGoodsList(communityGoods, pageBean);
    }

    //获取商品详情
    @ApiOperation(value="首页-获取商品详情", notes="首页-获取商品详情")
    @RequestMapping(value = "/queryGoodsById", method = {RequestMethod.GET})
    public Result<?> queryGoodsById(String goodsId){
        return goodsService.queryGoodsById(goodsId);
    }

    //商品收藏-获取我收藏的商品列表
    @ApiOperation(value="商品收藏-获取我收藏的商品列表", notes="商品收藏-获取我收藏的商品列表")
    @RequestMapping(value = "/queryGoodsCollectionList", method = {RequestMethod.POST})
    public Result<?> queryGoodsCollectionList(@RequestHeader("X-Access-Token") String token, PageBean pageBean){
        return goodsService.queryGoodsCollectionList(token, pageBean);
    }

    //兑换商品
    @ApiOperation(value="首页-兑换商品", notes="首页-兑换商品")
    @RequestMapping(value = "/buyGoods", method = {RequestMethod.POST})
    public Result<?> buyGoods(@RequestHeader("X-Access-Token") String token, CommunityOrder communityOrder){
        return goodsService.buyGoods(token, communityOrder);
    }

    //收藏商品
    @ApiOperation(value="首页-收藏商品", notes="首页-收藏商品")
    @RequestMapping(value = "/collectionGoods", method = {RequestMethod.POST})
    public Result<?> collectionGoods(@RequestHeader("X-Access-Token") String token, CommunityGoodsCollection communityGoodsCollection){
        return goodsService.collectionGoods(token, communityGoodsCollection);
    }
    
}
