package org.jeecg.modules.api.service.impl;

import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.config.shiro.ShiroRealm;
import org.jeecg.modules.api.bean.PageBean;
import org.jeecg.modules.api.service.ActivityService;
import org.jeecg.modules.communityActivity.entity.CommunityActivity;
import org.jeecg.modules.communityActivity.service.ICommunityActivityService;
import org.jeecg.modules.communityActivityApply.entity.CommunityActivityApply;
import org.jeecg.modules.communityActivityApply.service.ICommunityActivityApplyService;
import org.jeecg.modules.communityActivityCollection.entity.CommunityActivityCollection;
import org.jeecg.modules.communityActivityCollection.service.ICommunityActivityCollectionService;
import org.jeecg.modules.communityGoods.entity.CommunityGoods;
import org.jeecg.modules.communityGoodsCollection.entity.CommunityGoodsCollection;
import org.jeecg.modules.communityScore.entity.CommunityScore;
import org.jeecg.modules.communityScore.service.ICommunityScoreService;
import org.jeecg.modules.hanHaiMember.entity.HanHaiMember;
import org.jeecg.modules.hanHaiMember.service.IHanHaiMemberService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
@Slf4j
public class ActivityServiceImpl implements ActivityService {
    /******************************************************************************************************************/
    //权限验证
    @Resource
    private ShiroRealm shiroRealm;
    //活动信息
    @Resource
    private ICommunityActivityService communityActivityService;
    //活动收藏信息
    @Resource
    private ICommunityActivityCollectionService communityActivityCollectionService;
    //活动报名信息
    @Resource
    private ICommunityActivityApplyService communityActivityApplyService;
    //积分明细
    @Resource
    private ICommunityScoreService communityScoreService;
    //用户信息
    @Resource
    private IHanHaiMemberService hanHaiMemberService;
    /******************************************************************************************************************/

    //获取活动列表
    @Override
    public Result<?> queryActivityList(CommunityActivity communityActivity, PageBean pageBean) {
        log.info("开始查询活动信息");
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityActivity> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityActivity> query = null;
        //返回信息
        Page<CommunityActivity> pageList = null;

        try{
            //分页
            page = new Page<CommunityActivity>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityActivityService
                    .lambdaQuery();

            //组装查询条件
            if(StringUtils.isNotBlank(communityActivity.getId())){
                //id
                query.eq(CommunityActivity::getId, communityActivity.getId());
            }
            if(StringUtils.isNotBlank(communityActivity.getTitle())){
                //标题
                query.like(CommunityActivity::getTitle, communityActivity.getTitle());
            }
            if(StringUtils.isNotBlank(communityActivity.getCategoryId())){
                //活动类型
                query.eq(CommunityActivity::getCategoryId, communityActivity.getCategoryId());
            }
            if(StringUtils.isNotBlank(communityActivity.getStatus())){
                //活动状态
                query.eq(CommunityActivity::getStatus, communityActivity.getStatus());
            }
            if(StringUtils.isNotBlank(communityActivity.getIsHot())){
                //推荐活动
                query.eq(CommunityActivity::getIsHot, communityActivity.getIsHot());
            }

            //按照创建时间降序排列
            query.orderByDesc(CommunityActivity::getCreateTime);

            //获取活动信息
            pageList = query.page(page);

            log.info("活动信息查询结束");
            return Result.OK("活动列表", pageList);
        }catch (Exception e){
            log.info("活动信息查询失败");
            e.printStackTrace();
            return Result.error("活动列表查询失败");
        }
    }

    //获取活动信息详情
    @Override
    public Result<?> queryActivityById(String activityId) {
        log.info("开始查询活动信息详情");
        //返回信息
        String massege = "";

        try{
            CommunityActivity one = communityActivityService
                    .lambdaQuery()
                    .eq(CommunityActivity::getId, activityId)
                    .one();
            if(null == one){
                log.info("活动信息不存在，请检查活动id：{}", activityId);
                return Result.OK("活动信息不存在，请检查活动id："+activityId, one);
            }

            log.info("活动信息详情查询结束");
            return Result.OK("活动信息详情", one);
        }catch (Exception e){
            log.info("活动信息详情查询失败");
            e.printStackTrace();
            return Result.error("活动信息详情查询失败");
        }
    }

    //获取我收藏的活动列表
    @Override
    public Result<?> queryActivityCollectionList(String token, PageBean pageBean) {
        log.info("开始查询活动信息");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityActivityCollection> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityActivityCollection> query = null;
        //返回信息
        Page<CommunityActivityCollection> pageList = null;

        try{
            //1、获取活动列表
            //分页
            page = new Page<CommunityActivityCollection>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityActivityCollectionService
                    .lambdaQuery()
                    .eq(CommunityActivityCollection::getUserId, hanHaiMember.getId());

            //组装查询条件

            //按照创建时间降序排列
            query.orderByDesc(CommunityActivityCollection::getCreateTime);

            //获取活动信息
            pageList = query.page(page);

            //2、添加活动信息至收藏内
            for (CommunityActivityCollection record : pageList.getRecords()) {
                CommunityActivity one = communityActivityService
                        .lambdaQuery()
                        .eq(CommunityActivity::getId, record.getActivityId())
                        .one();
                record.setCommunityActivity(one);
            }

            log.info("活动信息查询结束");
            return Result.OK("活动列表", pageList);
        }catch (Exception e){
            log.info("活动信息查询失败");
            e.printStackTrace();
            return Result.error("活动列表查询失败");
        }
    }

    //获取我报名的活动列表
    @Override
    public Result<?> queryApplyList(String token, CommunityActivityApply communityActivityApply, PageBean pageBean) {
        log.info("开始查询活动信息");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityActivityApply> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityActivityApply> query = null;
        //返回信息
        Page<CommunityActivityApply> pageList = null;

        try{
            //1、获取活动列表
            //分页
            page = new Page<CommunityActivityApply>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityActivityApplyService
                    .lambdaQuery()
                    .eq(CommunityActivityApply::getUserId, hanHaiMember.getId());

            //组装查询条件
            //签到状态
            if(StringUtils.isNotBlank(communityActivityApply.getStatus())){
                query.eq(CommunityActivityApply::getStatus, communityActivityApply.getStatus());
            }

            //按照创建时间降序排列
            query.orderByDesc(CommunityActivityApply::getCreateTime);

            //获取活动信息
            pageList = query.page(page);

            //2、添加活动信息至报名活动列表内
            for (CommunityActivityApply record : pageList.getRecords()) {
                CommunityActivity one = communityActivityService
                        .lambdaQuery()
                        .eq(CommunityActivity::getId, record.getActivityId())
                        .one();
                record.setCommunityActivity(one);
            }

            log.info("活动信息查询结束");
            return Result.OK("活动列表", pageList);
        }catch (Exception e){
            log.info("活动信息查询失败");
            e.printStackTrace();
            return Result.error("活动列表查询失败");
        }
    }

    //收藏活动
    @Override
    public Result<?> collectionActivity(String token, CommunityActivityCollection communityActivityCollection) {
        log.info("收藏活动开始");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";

        try{
            //1、校验活动是否存在
            CommunityActivity activity = communityActivityService.getById(communityActivityCollection.getActivityId());
            if(null == activity){
                log.info("活动不存在，请检查活动id：{}", communityActivityCollection.getActivityId());
                return Result.error("活动不存在，请检查活动id：{}", communityActivityCollection.getActivityId());
            }

            //2、校验活动是否已被用户收藏
            CommunityActivityCollection collection = communityActivityCollectionService
                    .lambdaQuery()
                    .eq(CommunityActivityCollection::getActivityId, communityActivityCollection.getActivityId())
                    .eq(CommunityActivityCollection::getUserId, hanHaiMember.getId())
                    .one();

            //3、添加/取消收藏
            if(null == collection){
                //3.1、添加收藏
                log.info("执行添加收藏");
                communityActivityCollection.setUserId(hanHaiMember.getId());
                boolean result = communityActivityCollectionService.save(communityActivityCollection);

                //判断是否新增成功
                if(result){
                    log.info("收藏成功");
                    return Result.OK("收藏成功");
                }else {
                    log.info("收藏失败");
                    return Result.error("收藏失败");
                }

            }else {
                //3.2、取消收藏
                log.info("执行取消收藏");
                boolean result = communityActivityCollectionService.removeById(collection.getId());

                //判断是否新增成功
                if(result){
                    log.info("取消收藏成功");
                    return Result.OK("取消收藏成功");
                }else {
                    log.info("取消收藏失败");
                    return Result.error("取消收藏失败");
                }
            }

        }catch (Exception e){
            log.error("操作失败");
            e.printStackTrace();
            return Result.error("操作失败");
        }
    }

    //活动报名
    @Override
    public Result<?> applyActivity(String token, CommunityActivityApply communityActivityApply) {
        log.info("活动报名开始");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";

        try{
            //1、判断活动是否在报名中、报名人数是否已满
            CommunityActivity activity = communityActivityService
                    .lambdaQuery()
                    .eq(CommunityActivity::getStatus, 0)
                    .one();
            if(null == activity){
                log.info("活动不存在，请检查活动id：{}", communityActivityApply.getActivityId());
                return Result.OK("活动不存在，请检查活动id：{}", communityActivityApply.getActivityId());
            }else if(activity.getNumActivity() >= activity.getNumLimit()){
                log.info("活动报名人数已满");
                return Result.OK("活动报名人数已满");
            }

            //2、判断用户是否已经报名过活动
            CommunityActivityApply apply = communityActivityApplyService
                    .lambdaQuery()
                    .eq(CommunityActivityApply::getUserId, hanHaiMember.getId())
                    .eq(CommunityActivityApply::getActivityId, communityActivityApply.getActivityId())
                    .one();
            if(null != apply){
                log.info("用户已报名过该活动，请勿重复报名");
                return Result.OK("用户已报名过该活动，请勿重复报名");
            }else {
                //3、添加报名信息
                log.info("添加报名信息");
                communityActivityApply.setUserId(hanHaiMember.getId());
                boolean result1 = communityActivityApplyService.save(communityActivityApply);

                //4、活动添加报名人数
                log.info("活动添加报名人数");
                int oldnum = activity.getNumActivity();
                int newnum = oldnum + 1;
                activity.setNumActivity(newnum);
                boolean result2 = communityActivityService.updateById(activity);

                //判断是否新增成功
                if(result1 && result2){
                    log.info("活动报名成功");
                    return Result.OK("活动报名成功");
                }else {
                    log.info("活动报名失败");
                    return Result.error("活动报名失败");
                }
            }
        }catch (Exception e){
            log.error("活动报名失败");
            e.printStackTrace();
            return Result.error("活动报名失败");
        }
    }

    //活动签到
    @Override
    public Result<?> signActivity(String token, String activityId) {
        log.info("活动签到开始");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";

        try{
            //1、判断活动是否在进行中
            CommunityActivity activity = communityActivityService
                    .lambdaQuery()
                    .eq(CommunityActivity::getId, activityId)
                    .in(CommunityActivity::getStatus, 0, 1)
                    .one();
            if(null == activity){
                log.info("活动不存在或已经结束，请检查活动id：{}", activityId);
                return Result.OK("活动不存在或已经结束，请检查活动id：{}", activityId);
            }

            //2、判断用户是否已经签到过活动
            CommunityActivityApply apply = communityActivityApplyService
                    .lambdaQuery()
                    .eq(CommunityActivityApply::getUserId, hanHaiMember.getId())
                    .eq(CommunityActivityApply::getActivityId, activityId)
                    .eq(CommunityActivityApply::getStatus, 0)
                    .one();
            if(null == apply){
                log.info("报名活动不存在或已经签到过，请检查活动id：{}", activityId);
                return Result.OK("报名活动不存在或已经签到过，请检查活动id：{}", activityId);
            }else {
                //3、添加签到信息
                apply.setStatus("1");
                boolean result1 = communityActivityApplyService.updateById(apply);

                //4、添加用户积分
                int oldScore = hanHaiMember.getScore();
                int newScore = oldScore + activity.getScore();
                hanHaiMember.setScore(newScore);
                boolean result2 = hanHaiMemberService.updateById(hanHaiMember);

                //4、添加用户积分记录
                CommunityScore score = new CommunityScore();
                score.setTitle(activity.getTitle());
                score.setScore(activity.getScore());
                score.setType("0");//0-收入 1-支出
                score.setUserId(hanHaiMember.getId());
                boolean result3 = communityScoreService.save(score);


                //判断是否签到成功
                if(result1 && result2 && result3){
                    return Result.OK("活动签到成功");
                }else {
                    return Result.error("活动签到失败");
                }
            }
        }catch (Exception e){
            log.error("活动签到失败");
            e.printStackTrace();
            return Result.error("活动签到失败");
        }
    }
}
