package org.jeecg.modules.api.service.impl;

import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.api.bean.PageBean;
import org.jeecg.modules.api.service.ConfigService;
import org.jeecg.modules.communityCareer.entity.CommunityCareer;
import org.jeecg.modules.communityCareer.service.ICommunityCareerService;
import org.jeecg.modules.communityConfig.entity.CommunityConfig;
import org.jeecg.modules.communityConfig.service.ICommunityConfigService;
import org.jeecg.modules.communityQualifications.entity.CommunityQualifications;
import org.jeecg.modules.communityQualifications.service.ICommunityQualificationsService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
@Slf4j
public class ConfigServiceImpl implements ConfigService {

    /******************************************************************************************************************/
    //系统配置信息
    @Resource
    private ICommunityConfigService communityConfigService;
    //职业信息
    @Resource
    private ICommunityCareerService communityCareerService;
    //学历信息
    @Resource
    private ICommunityQualificationsService communityQualificationsService;
    /******************************************************************************************************************/
    //查询系统配置列表
    @Override
    public Result<?> queryConfigList(PageBean pageBean) {
        log.info("开始查询系统配置列表");
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityConfig> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityConfig> query = null;
        //返回信息
        Page<CommunityConfig> pageList = null;

        try{
            //分页
            page = new Page<CommunityConfig>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityConfigService
                    .lambdaQuery();

            //组装查询条件
            //按照创建时间降序排列
            query.orderByDesc(CommunityConfig::getCreateTime);

            //获取系统配置列表信息
            pageList = query.page(page);

            log.info("系统配置查询结束");
            return Result.OK("系统配置列表", pageList);
        }catch (Exception e){
            log.error("系统配置查询失败");
            e.printStackTrace();
            return Result.error("系统配置列表查询失败");
        }
    }

    //查询系统配置详情
    @Override
    public Result<?> queryConfigByParamCode(String paramCode) {
        log.info("开始查询系统配置详情");
        //返回信息
        String massege = "";

        try{
            CommunityConfig config = communityConfigService
                    .lambdaQuery()
                    .eq(CommunityConfig::getParamCode, paramCode)
                    .one();

            log.info("系统配置详情查询结束");
            return Result.OK("配置详情", config);
        }catch (Exception e){
            log.error("系统配置详情查询失败");
            e.printStackTrace();
            return Result.error("配置详情查询失败");
        }
    }

    //查询职业信息列表
    @Override
    public Result<?> queryCareerList(PageBean pageBean) {
        log.info("开始查询职业信息列表");
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityCareer> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityCareer> query = null;
        //返回信息
        Page<CommunityCareer> pageList = null;

        try{
            //分页
            page = new Page<CommunityCareer>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityCareerService
                    .lambdaQuery();

            //组装查询条件
            //按照创建时间降序排列
            query.orderByDesc(CommunityCareer::getCreateTime);

            //获取系统配置列表信息
            pageList = query.page(page);

            log.info("职业信息查询结束");
            return Result.OK("职业信息列表", pageList);
        }catch (Exception e){
            log.error("职业信息查询失败");
            e.printStackTrace();
            return Result.error("职业信息列表查询失败");
        }
    }

    //查询学历信息列表
    @Override
    public Result<?> queryQualificationList(PageBean pageBean) {
        log.info("开始查询学历信息列表");
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityQualifications> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityQualifications> query = null;
        //返回信息
        Page<CommunityQualifications> pageList = null;

        try{
            //分页
            page = new Page<CommunityQualifications>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityQualificationsService
                    .lambdaQuery();

            //组装查询条件
            //按照创建时间降序排列
            query.orderByDesc(CommunityQualifications::getCreateTime);

            //获取学历信息列表信息
            pageList = query.page(page);

            log.info("学历信息查询结束");
            return Result.OK("学历信息列表", pageList);
        }catch (Exception e){
            log.error("学历信息查询失败");
            e.printStackTrace();
            return Result.error("学历信息列表查询失败");
        }
    }
}
