package org.jeecg.modules.api.service.impl;

import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.config.shiro.ShiroRealm;
import org.jeecg.modules.api.bean.PageBean;
import org.jeecg.modules.api.service.GoodsService;
import org.jeecg.modules.communityActivity.entity.CommunityActivity;
import org.jeecg.modules.communityGoods.entity.CommunityGoods;
import org.jeecg.modules.communityGoods.service.ICommunityGoodsService;
import org.jeecg.modules.communityGoodsCollection.entity.CommunityGoodsCollection;
import org.jeecg.modules.communityGoodsCollection.service.ICommunityGoodsCollectionService;
import org.jeecg.modules.communityOrder.entity.CommunityOrder;
import org.jeecg.modules.communityOrder.service.ICommunityOrderService;
import org.jeecg.modules.communityScore.entity.CommunityScore;
import org.jeecg.modules.communityScore.service.ICommunityScoreService;
import org.jeecg.modules.hanHaiMember.entity.HanHaiMember;
import org.jeecg.modules.hanHaiMember.service.IHanHaiMemberService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
@Slf4j
public class GoodsServiceImpl implements GoodsService {

    /******************************************************************************************************************/
    //权限验证
    @Resource
    private ShiroRealm shiroRealm;
    //商品信息
    @Resource
    private ICommunityGoodsService communityGoodsService;
    //订单信息
    @Resource
    private ICommunityOrderService communityOrderService;
    //商品收藏信息
    @Resource
    private ICommunityGoodsCollectionService communityGoodsCollectionService;
    //积分明细
    @Resource
    private ICommunityScoreService communityScoreService;
    //用户信息
    @Resource
    private IHanHaiMemberService hanHaiMemberService;
    /******************************************************************************************************************/
    
    //获取商品列表
    @Override
    public Result<?> queryGoodsList(CommunityGoods communityGoods, PageBean pageBean) {
        log.info("开始查询商品信息");
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityGoods> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityGoods> query = null;
        //返回信息
        Page<CommunityGoods> pageList = null;

        try{
            //分页
            page = new Page<CommunityGoods>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityGoodsService
                    .lambdaQuery();

            //组装查询条件
            //标题
            if(StringUtils.isNotBlank(communityGoods.getTitle())){
                query.like(CommunityGoods::getTitle, communityGoods.getTitle());
            }
            //分类
            if(StringUtils.isNotBlank(communityGoods.getCategoryId())){
                query.eq(CommunityGoods::getCategoryId, communityGoods.getCategoryId());
            }
            //价格
            if(null != communityGoods.getPrice()){
                switch (communityGoods.getPrice()){
                    case 0:
                        //价格升序排列
                        query.orderByAsc(CommunityGoods::getPrice);
                        break;
                    case 1:
                        //价格升序排列
                        query.orderByDesc(CommunityGoods::getPrice);
                        break;
                }
            }
            //兑换量
            if(null != communityGoods.getSales()){
                switch (communityGoods.getSales()){
                    case 0:
                        //兑换量升序排列
                        query.orderByAsc(CommunityGoods::getPrice);
                        break;
                    case 1:
                        //兑换量升序排列
                        query.orderByDesc(CommunityGoods::getPrice);
                        break;
                }
            }

            if(null == communityGoods.getPrice()  && null == communityGoods.getSales()){
                //按照创建时间降序排列
                query.orderByDesc(CommunityGoods::getCreateTime);
            }

            //获取商品信息
            pageList = query.page(page);

            log.info("商品信息查询结束");
            return Result.OK("商品列表", pageList);
        }catch (Exception e){
            log.info("商品信息查询失败");
            e.printStackTrace();
            return Result.error("商品列表查询失败");
        }
    }

    //获取商品列表
    @Override
    public Result<?> queryGoodsById(String goodsId) {
        log.info("开始查询商品信息详情");
        //返回信息
        String massege = "";

        try{
            CommunityGoods one = communityGoodsService
                    .lambdaQuery()
                    .eq(CommunityGoods::getId, goodsId)
                    .one();
            if(null == one){
                log.info("商品信息不存在，请检查商品id：{}", goodsId);
                return Result.OK("商品信息不存在，请检查商品id："+goodsId, one);
            }

            log.info("商品信息详情查询结束");
            return Result.OK("商品信息详情", one);
        }catch (Exception e){
            log.info("商品信息详情查询失败");
            e.printStackTrace();
            return Result.error("商品信息详情查询失败");
        }
    }

    //商品收藏-获取我收藏的商品列表/详情
    @Override
    public Result<?> queryGoodsCollectionList(String token, PageBean pageBean) {
        log.info("开始查询商品信息");
        //权限验证
        //HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityGoodsCollection> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityGoodsCollection> query = null;
        //返回信息
        Page<CommunityGoodsCollection> pageList = null;

        try{
            //1、获取收藏商品列表
            //分页
            page = new Page<CommunityGoodsCollection>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityGoodsCollectionService
                    .lambdaQuery()
                    .eq(CommunityGoodsCollection::getUserId, hanHaiMember.getId());

            //组装查询条件

            //按照创建时间降序排列
            query.orderByDesc(CommunityGoodsCollection::getCreateTime);

            //获取商品信息
            pageList = query.page(page);

            //2、将商品信息添加到收藏列表中
            for (CommunityGoodsCollection record : pageList.getRecords()) {
                CommunityGoods one = communityGoodsService
                        .lambdaQuery()
                        .eq(CommunityGoods::getId, record.getGoodsId())
                        .one();
                record.setCommunityGoods(one);
            }

            log.info("商品信息查询结束");
            return Result.OK("商品列表", pageList);
        }catch (Exception e){
            log.info("商品信息查询失败");
            e.printStackTrace();
            return Result.error("商品列表查询失败");
        }
    }

    //兑换商品
    @Override
    public Result<?> buyGoods(String token, CommunityOrder communityOrder) {
        log.info("兑换商品开始");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";

        try{
            //0、校验商品是否存在
            CommunityGoods goods = communityGoodsService.getById(communityOrder.getGoodsId());
            if(null == goods){
                log.info("商品不存在，请检查商品id：{}", communityOrder.getGoodsId());
                return Result.error("商品不存在，请检查商品id：{}", communityOrder.getGoodsId());
            }

            //1、校验用户积分是否足够
            if(hanHaiMember.getScore() < goods.getPrice()){
                log.info("积分不足，兑换失败");
                return Result.error("积分不足，兑换失败");
            }

            //2、校验商品库存是否足够
            if(goods.getInventory() < 1){
                log.info("商品库存不足，兑换失败");
                return Result.error("商品库存不足，兑换失败");
            }

            //3、添加订单信息
            log.info("添加订单信息");
            communityOrder.setUserId(hanHaiMember.getId());
            communityOrder.setTitle(goods.getTitle()+"兑换");
            communityOrder.setImage(goods.getImage());
            communityOrder.setPrice(goods.getPrice());
            boolean result1 = communityOrderService.save(communityOrder);

            //4、商品库存减少
            log.info("减少商品库存");
            int oldInventory = goods.getInventory();
            int newInventory = oldInventory - 1;
            goods.setInventory(newInventory);
            boolean result2 = communityGoodsService.updateById(goods);

            //5、用户积分减少
            log.info("减少用户积分");
            int oldScore = hanHaiMember.getScore();
            int newScore = oldScore - goods.getPrice();
            hanHaiMember.setScore(newScore);
            boolean result3 = hanHaiMemberService.updateById(hanHaiMember);

            //6、添加用户积分记录
            log.info("添加用户积分记录");
            CommunityScore score = new CommunityScore();
            score.setTitle(goods.getTitle());
            score.setScore(goods.getPrice());
            score.setType("1");//0-收入 1-支出
            score.setUserId(hanHaiMember.getId());
            boolean result4 = communityScoreService.save(score);

            //判断是否新增成功
            if(result1 && result2 && result3 && result4){
                log.info("兑换商品成功");
                return Result.OK("兑换商品成功");
            }else {
                log.info("兑换商品失败");
                return Result.OK("兑换商品失败");
            }

        }catch (Exception e){
            log.error("兑换商品失败");
            e.printStackTrace();
            return Result.error("兑换商品失败");
        }
    }

    //收藏商品
    @Override
    public Result<?> collectionGoods(String token, CommunityGoodsCollection communityGoodsCollection) {
        log.info("收藏商品开始");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";

        try{
            //1、校验商品是否存在
            CommunityGoods goods = communityGoodsService.getById(communityGoodsCollection.getGoodsId());
            if(null == goods){
                log.info("商品不存在，请检查商品id：{}", communityGoodsCollection.getGoodsId());
                return Result.error("商品不存在，请检查商品id：{}", communityGoodsCollection.getGoodsId());
            }

            //2、校验商品是否已被用户收藏
            CommunityGoodsCollection collection = communityGoodsCollectionService
                    .lambdaQuery()
                    .eq(CommunityGoodsCollection::getGoodsId, communityGoodsCollection.getGoodsId())
                    .eq(CommunityGoodsCollection::getUserId, hanHaiMember.getId())
                    .one();

            //3、添加/取消收藏
            if(null == collection){
                //3.1、添加收藏
                log.info("执行添加收藏");
                communityGoodsCollection.setUserId(hanHaiMember.getId());
                boolean result = communityGoodsCollectionService.save(communityGoodsCollection);

                //判断是否新增成功
                if(result){
                    log.info("收藏成功");
                    return Result.OK("收藏成功");
                }else {
                    log.info("收藏失败");
                    return Result.error("收藏失败");
                }

            }else {
                //3.2、取消收藏
                log.info("执行取消收藏");
                boolean result = communityGoodsCollectionService.removeById(collection.getId());

                //判断是否新增成功
                if(result){
                    log.info("取消收藏成功");
                    return Result.OK("取消收藏成功");
                }else {
                    log.info("取消收藏失败");
                    return Result.error("取消收藏失败");
                }
            }

        }catch (Exception e){
            log.error("操作失败");
            e.printStackTrace();
            return Result.error("操作失败");
        }
    }
}
