package org.jeecg.modules.api.service.impl;

import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.config.shiro.ShiroRealm;
import org.jeecg.modules.api.bean.PageBean;
import org.jeecg.modules.api.service.IndexService;
import org.jeecg.modules.communityBanner.entity.CommunityBanner;
import org.jeecg.modules.communityBanner.service.ICommunityBannerService;
import org.jeecg.modules.communityNotice.entity.CommunityNotice;
import org.jeecg.modules.communityNotice.service.ICommunityNoticeService;
import org.jeecg.modules.communityOrder.entity.CommunityOrder;
import org.jeecg.modules.communityVolunteer.entity.CommunityVolunteer;
import org.jeecg.modules.communityVolunteer.service.ICommunityVolunteerService;
import org.jeecg.modules.hanHaiMember.entity.HanHaiMember;
import org.jeecg.modules.hanHaiMember.service.IHanHaiMemberService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
@Slf4j
public class IndexServiceImpl implements IndexService {

    /******************************************************************************************************************/
    //权限验证
    @Resource
    private ShiroRealm shiroRealm;
    //轮播图信息
    @Resource
    private ICommunityBannerService communityBannerService;
    //公告信息
    @Resource
    private ICommunityNoticeService communityNoticeService;
    //志愿者信息
    @Resource
    private ICommunityVolunteerService communityVolunteerService;
    //用户信息
    @Resource
    private IHanHaiMemberService hanHaiMemberService;
    /******************************************************************************************************************/

    //获取banner图列表
    @Override
    public Result<?> queryBannerList(CommunityBanner communityBanner, PageBean pageBean) {
        log.info("开始查询轮播图信息");
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityBanner> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityBanner> query = null;
        //返回信息
        Page<CommunityBanner> pageList = null;

        try{
            //分页
            page = new Page<CommunityBanner>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityBannerService
                    .lambdaQuery();

            //组装查询条件
            if(StringUtils.isNotBlank(communityBanner.getTitle())){
                //标题
                query.like(CommunityBanner::getTitle, communityBanner.getTitle());
            }
            if(StringUtils.isNotBlank(communityBanner.getType())){
                //分类
                query.eq(CommunityBanner::getType, communityBanner.getType());
            }

            //按照排序编号升序排列
            query.orderByAsc(CommunityBanner::getOrderNo);

            //获取轮播图信息
            pageList = query.page(page);

            log.info("轮播图信息查询结束");
            return Result.OK("轮播图列表", pageList);
        }catch (Exception e){
            log.info("轮播图信息查询失败");
            e.printStackTrace();
            return Result.error("轮播图列表查询失败");
        }
    }

    //获取公告列表/详情
    @Override
    public Result<?> queryNoticeList(CommunityNotice communityNotice, PageBean pageBean) {
        log.info("开始查询公告信息");
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityNotice> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityNotice> query = null;
        //返回信息
        Page<CommunityNotice> pageList = null;

        try{
            //分页
            page = new Page<CommunityNotice>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityNoticeService
                    .lambdaQuery();

            //组装查询条件
            if(StringUtils.isNotBlank(communityNotice.getId())){
                //id
                query.eq(CommunityNotice::getId, communityNotice.getId());
            }
            if(StringUtils.isNotBlank(communityNotice.getTitle())){
                //标题
                query.like(CommunityNotice::getTitle, communityNotice.getTitle());
            }

            //按照创建时间降序排列
            query.orderByDesc(CommunityNotice::getCreateTime);

            //获取公告信息
            pageList = query.page(page);

            log.info("公告信息查询结束");
            return Result.OK("公告列表", pageList);
        }catch (Exception e){
            log.info("公告信息查询失败");
            e.printStackTrace();
            return Result.error("公告列表查询失败");
        }
    }

    //获取公告详情
    @Override
    public Result<?> queryNoticeById(String noticeId) {
        log.info("开始查询公告信息");
        //返回信息
        String massege = "";

        try{
            //1、查询公告详情
            CommunityNotice one = communityNoticeService.getById(noticeId);
            if(null == one){
                log.info("公告信息不存在，请检查公告id：{}", noticeId);
                return Result.OK("公告信息不存在，请检查公告id："+noticeId, one);
            }

            //2、返回公告信息
            log.info("公告信息查询结束");
            return Result.OK("公告信息", one);
        }catch (Exception e){
            log.info("公告信息查询失败");
            e.printStackTrace();
            return Result.error("公告查询失败");
        }
    }

    //申请成为志愿者
    @Override
    public Result<?> applyVolunteer(String token, CommunityVolunteer communityVolunteer) {
        log.info("申请成为志愿者表单提交开始");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";

        try{
            //1、判断用户是否已经成为志愿者
            CommunityVolunteer volunteer = communityVolunteerService
                    .lambdaQuery()
                    .eq(CommunityVolunteer::getUserId, hanHaiMember.getId())
                    .one();
            if(null != volunteer){
                log.info("您已经是志愿者了！");
                return Result.OK("您已经是志愿者了！");
            }

            communityVolunteer.setUserId(hanHaiMember.getId());
            boolean result = communityVolunteerService.save(communityVolunteer);
            //判断是否新增成功
            log.info("申请成为志愿者表单提交结束");
            if(result){
                return Result.OK("信息添加成功");
            }else {
                return Result.OK("信息添加失败");
            }

        }catch (Exception e){
            log.error("申请成为志愿者表单提交失败");
            e.printStackTrace();
            return Result.error("信息添加失败");
        }
    }
}
