package org.jeecg.modules.api.service.impl;

import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.config.shiro.ShiroRealm;
import org.jeecg.modules.api.bean.PageBean;
import org.jeecg.modules.api.service.OrderService;
import org.jeecg.modules.communityOrder.entity.CommunityOrder;
import org.jeecg.modules.communityOrder.service.ICommunityOrderService;
import org.jeecg.modules.hanHaiMember.entity.HanHaiMember;
import org.jeecg.modules.hanHaiMember.service.IHanHaiMemberService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
@Slf4j
public class OrderServiceImpl implements OrderService {


    /******************************************************************************************************************/
    //权限验证
    @Resource
    private ShiroRealm shiroRealm;
    //订单信息
    @Resource
    private ICommunityOrderService communityOrderService;
    //用户信息
    @Resource
    private IHanHaiMemberService hanHaiMemberService;
    /******************************************************************************************************************/

    //查看订单列表
    @Override
    public Result<?> queryOrderList(String token, CommunityOrder communityOrder, PageBean pageBean) {
        log.info("开始查询订单信息");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityOrder> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityOrder> query = null;
        //返回信息
        Page<CommunityOrder> pageList = null;

        try{
            //分页
            page = new Page<CommunityOrder>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityOrderService
                    .lambdaQuery()
                    .eq(CommunityOrder::getUserId, hanHaiMember.getId());

            //组装查询条件
            //标题
            if(StringUtils.isNotBlank(communityOrder.getTitle())){
                query.like(CommunityOrder::getTitle, communityOrder.getTitle());
            }
            //状态
            if(StringUtils.isNotBlank(communityOrder.getStatus())){
                query.like(CommunityOrder::getStatus, communityOrder.getStatus());
            }

            //按照创建时间降序排列
            query.orderByDesc(CommunityOrder::getCreateTime);

            //获取订单信息
            pageList = query.page(page);

            log.info("订单信息查询结束");
            return Result.OK("订单列表", pageList);
        }catch (Exception e){
            log.info("订单信息查询失败");
            e.printStackTrace();
            return Result.error("订单列表查询失败");
        }
    }

    //查看订单详情
    @Override
    public Result<?> queryOrderById(String token, String orderId) {
        log.info("开始查询订单信息");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";

        try{
            //1、查询用户是否拥有订单
           CommunityOrder order = communityOrderService
                   .lambdaQuery()
                   .eq(CommunityOrder::getId, orderId)
                   .eq(CommunityOrder::getUserId, hanHaiMember.getId())
                   .one();
            if(null != order){
                log.info("订单不存在，请检查订单编号：{}", orderId);
                return Result.OK("订单不存在，请检查订单编号：{}", orderId);
            }

            //2、返回订单信息
            log.info("订单信息查询结束");
            return Result.OK("订单信息", order);
        }catch (Exception e){
            log.info("订单信息查询失败");
            e.printStackTrace();
            return Result.error("订单信息查询失败");
        }
    }

    //确认取货
    @Override
    public Result<?> finishOrder(String token, String orderId) {
        log.info("开始确认收货");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);
        //返回信息
        String massege = "";

        try{
            //1、查询用户是否拥有订单
            CommunityOrder order = communityOrderService
                    .lambdaQuery()
                    .eq(CommunityOrder::getId, orderId)
                    .eq(CommunityOrder::getUserId, hanHaiMember.getId())
                    .one();
            if(null == order){
                log.info("订单不存在，请检查订单编号：{}", orderId);
                return Result.OK("订单不存在，请检查订单编号：{}", orderId);
            }

            //2、确认收货
            order.setStatus("1");
            boolean result = communityOrderService.updateById(order);
            if(result){
                log.info("确认收货成功");
                return Result.OK("确认收货成功");
            }else {
                log.info("确认收货失败");
                return Result.error("确认收货失败");
            }

        }catch (Exception e){
            log.info("确认收货失败");
            e.printStackTrace();
            return Result.error("确认收货失败");
        }
    }
}
