package org.jeecg.modules.api.service.impl;

import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.config.shiro.ShiroRealm;
import org.jeecg.modules.api.bean.PageBean;
import org.jeecg.modules.api.service.ScoreService;
import org.jeecg.modules.communityScore.entity.CommunityScore;
import org.jeecg.modules.communityScore.service.ICommunityScoreService;
import org.jeecg.modules.hanHaiMember.entity.HanHaiMember;
import org.jeecg.modules.hanHaiMember.service.IHanHaiMemberService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
@Slf4j
public class ScoreServiceImpl implements ScoreService {

    /******************************************************************************************************************/
    //权限验证
    @Resource
    private ShiroRealm shiroRealm;
    //积分信息
    @Resource
    private ICommunityScoreService communityScoreService;
    //用户信息
    @Resource
    private IHanHaiMemberService hanHaiMemberService;
    /******************************************************************************************************************/

    //可用积分-获取积分明细列表
    @Override
    public Result<?> queryScoreList(String token, CommunityScore communityScore, PageBean pageBean) {
        log.info("开始查询积分信息");
        //权限验证
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //HanHaiMember hanHaiMember = hanHaiMemberService.getById(token);

        //返回信息
        String massege = "";
        //分页信息
        Page<CommunityScore> page = null;
        //查询信息
        LambdaQueryChainWrapper<CommunityScore> query = null;
        //返回信息
        Page<CommunityScore> pageList = null;

        try{
            //分页
            page = new Page<CommunityScore>(pageBean.getPageNo(), pageBean.getPageSize());
            query = communityScoreService
                    .lambdaQuery()
                    .eq(CommunityScore::getUserId, hanHaiMember.getId());

            //组装查询条件
            if(StringUtils.isNotBlank(communityScore.getTitle())){
                //标题
                query.like(CommunityScore::getTitle, communityScore.getTitle());
            }
            if(StringUtils.isNotBlank(communityScore.getType())){
                //积分类型
                query.eq(CommunityScore::getType, communityScore.getType());
            }

            //按照创建时间降序排列
            query.orderByDesc(CommunityScore::getCreateTime);

            //获取积分信息
            pageList = query.page(page);

            log.info("积分信息查询结束");
            return Result.OK("积分列表", pageList);
        }catch (Exception e){
            log.info("积分信息查询失败");
            e.printStackTrace();
            return Result.error("积分列表查询失败");
        }
    }
}
